#!/bin/perl


#this is the root of the package users' homes
$pkg_home_root =  "/pkg";


if ($ARGV[0] eq "--help"){
  print <<"HERE";

pkg -- create a package user.

syntax:
  pkg package-name description
  pkg --help 
  
Create a package user for the purpose of compiling
a particular package.

The user will be created with user and group both
equal to the name you specify.

You will then be put into the user home
directory where you may proceed with
compiling/installing the package.

If the user already exists, this is equivalent to 
  su --login package-name

Written by Robert McIntyre. This software is free
software and is released to the public domain.
  
HERE
exit 0;
}
$" = " ";

$pkg_name = $ARGV[0];

$pkg_desc = $ARGV[1];

# Validate pkg_user as a user name.
if (!($pkg_name =~ m/^[a-z_][a-z0-9_-]*\$?$/)){
  print "$pkg_name is not a valid user name!\n";
  exit 1;
}

# Validate description.
if ($pkg_desc =~ m/:/){
  print "Package Description cannot contain \":\"\n";
  exit 1;
}

$pkg_home = "$pkg_home_root/$pkg_name";

#set default for $pkg_desc.
if (!($pkg_desc)){$pkg_desc = $pkg_name;}

@pkg_switch_cmd =  ("su", "--login", $pkg_name);

@pkg_create_cmd =
  ("useradd", "-c", $pkg_desc, "-d", $pkg_home, 
   "-g", $pkg_name, "-s", "/bin/bash",
   $pkg_name);

@pkg_create_group_cmd =
  ("groupadd", "--force", $pkg_name);

@pkg_create_home_cmd = 
  ("install", "-d", "-g", $pkg_name, "-o", $pkg_name, 
   "-m", "755", $pkg_home);

@pkg_add_install_cmd = 
  ("gpasswd", "--add", $pkg_name, "install");

sub copy_default_file {
  execute(("install", "-g", $pkg_name, "-o", $pkg_name,
	   "/pkg/skel/$_[0]", "$pkg_home"));
}


@pkg_link_bashrc_cmd =
("install", "-g", $pkg_name, "-o", $pkg_name,
   "/pkg/skel/.profile", "$pkg_home/.profile");

@pkg_copy_hg_wrapper_cmd =
  ("install", "-g", "root", "-o", "root",
   "-m", "6111", "/pkg/skel/hg-wrapper", "$pkg_home/.hg-wrapper");

@pkg_copy_save_acls_cmd =
  ("install", "-g", "root", "-o", "root",
   "-m", "6111", "/pkg/skel/save-acls", "$pkg_home/.save-acls");

sub execute{print "\t@_\n"; system(@_) and die $!;}

#determine if the user already exists:
`id $pkg_name 2>/dev/null`;
if (!$?){
  print "Change user.\n";
  execute(@pkg_switch_cmd); exit 0;}

print "Creating package group.\n";
execute(@pkg_create_group_cmd);

print "Creating package user.\n";
execute(@pkg_create_cmd);

print "Create home directory for $pkg_name.\n";
execute(@pkg_create_home_cmd);

print "Add $pkg_name to install group.\n";
execute(@pkg_add_install_cmd);

print "Copy Default Files.\n";

execute(@pkg_copy_hg_wrapper_cmd);
execute(@pkg_copy_save_acls_cmd);
copy_default_file(".profile");

#execute(@pkg_link_bashrc_cmd);
#execute(@pkg_copy_hgrc_cmd);

print "Change user.\n";
execute(@pkg_switch_cmd);
